import { NgTemplateOutlet, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, Component, viewChild, model, output, forwardRef, NgModule, Optional, SkipSelf } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule, NG_VALUE_ACCESSOR, ReactiveFormsModule } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialogActions, MatDialogClose, MatDialogContent, MatDialogRef, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { MatIcon, MatIconModule } from '@angular/material/icon';
import { MatTooltip, MatTooltipModule } from '@angular/material/tooltip';
import { QuillEditorComponent, QuillModule as QuillModule$1 } from 'ngx-quill';
import { MatButton, MatButtonModule } from '@angular/material/button';
import { MatFormField, MatFormFieldModule } from '@angular/material/form-field';
import { MatInput, MatInputModule } from '@angular/material/input';

;

const DefaultButtons = {
    //#region Font Style
    bold: true,
    italic: true,
    strike: true,
    underline: true,
    //#endregion
    //#region Media
    link: true,
    image: true,
    video: true,
    //#endregion
    //#region Block Style
    blockquote: true,
    codeblock: true,
    //#endregion
    //#region Heading Style
    h1: true,
    h2: true,
    //#endregion
    //#region Color
    color: true,
    //#endregion
    //#region List Style
    bulleted: true,
    ordered: true,
    //#endregion
    //#region Script Style
    subScript: true,
    superScript: true,
    //#endregion
    //#region Indent Style
    increaseIndent: true,
    decreaseIndent: true,
    //#endregion
    //#region DropDowns
    align: true,
    font: true,
    fontSize: true,
    headingStyle: true,
    //#endregion
    //#region Single Buttons
    clean: true,
    formula: true,
    rtl: true,
    editorSize: true,
    rawEditor: false,
    //#endregion
};

const DefaultIcons = {
    maximize: 'open_in_full',
    minimize: 'close_fullscreen',
    popout: 'open_in_full',
    popin: 'done'
};

const DefaultTooltips = {
    //#region Font Style
    bold: 'Bold',
    italic: 'Italic',
    strike: 'Strikethrough',
    underline: 'Underline',
    //#endregion
    //#region Media
    link: 'Link',
    image: 'Insert Image',
    video: 'Insert Video',
    //#endregion
    //#region Block Style
    blockquote: 'Blockquote',
    codeblock: 'Code Block',
    //#endregion
    //#region Heading Style
    h1: 'Heading 1',
    h2: 'Heading 2',
    //#endregion
    //#region Color
    color: 'Font / Background Color',
    //#endregion
    //#region List Style
    bulleted: 'Bulleted List',
    ordered: 'Ordered List',
    //#endregion
    //#region Script Style
    subScript: 'Subscript',
    superScript: 'Superscript',
    //#endregion
    //#region Indent Style
    increaseIndent: 'Increase Indent',
    decreaseIndent: 'Decrease Indent',
    //#endregion
    //#region DropDowns
    align: 'Align',
    font: 'Font',
    fontSize: 'Font Size',
    headingStyle: 'Heading',
    //#endregion
    //#region Single Buttons
    clean: 'Clean',
    formula: 'Formula',
    rtl: 'Right-To-Left',
    maximize: 'Maximize',
    minimize: 'Minimize',
    popout: 'Popout',
    popin: 'Done',
    rawEditor: 'Edit raw HTML (dangerous!)'
    //#endregion
};

const DefaultConfig = {
    buttons: DefaultButtons,
    icons: DefaultIcons,
    tooltips: DefaultTooltips,
    //#region These can be overriden via input()
    format: 'html',
    height: '50vh',
    width: '100%',
    fullscreenHeight: '85vh',
    fullscreenWidth: '100%',
    enableTooltips: true,
    fullscreen: false,
    fullscreenMode: 'popout',
    readonly: false,
    applyReadonlyStyle: true,
    showToolbar: true,
    showBorder: true,
    //#region Optional Quill modules
    imageResizeModule: true,
    imageDropModule: true,
    syntaxModule: true
    //#endregion
    //#endregion
};

;

;

;

class RawComponent {
    constructor() {
        this.data = inject(MAT_DIALOG_DATA);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: RawComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.0", type: RawComponent, isStandalone: true, selector: "cpquill-raw", ngImport: i0, template: "<mat-dialog-content>\r\n    <form>\r\n        <mat-form-field appearance=\"outline\">\r\n            <textarea matInput [(ngModel)]=\"data\" name=\"data\"></textarea>\r\n        </mat-form-field>\r\n    </form>\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions>\r\n    <button mat-raised-button color=\"warn\" mat-dialog-close=\"__DO!!NOT!!UPDATE__\">\r\n        <mat-icon>cancel</mat-icon>\r\n        <span>Cancel</span>\r\n    </button>\r\n\r\n    <button mat-raised-button color=\"primary\" [mat-dialog-close]=\"data\">\r\n        <mat-icon>done</mat-icon>\r\n        <span>Accept</span>\r\n    </button>\r\n</mat-dialog-actions>", styles: ["mat-dialog-content{height:95%;max-height:initial!important}form{width:100%}mat-form-field{width:100%}textarea{height:70vh}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "component", type: MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: RawComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cpquill-raw', standalone: true, imports: [
                        FormsModule,
                        MatButton,
                        MatDialogActions,
                        MatDialogClose,
                        MatDialogContent,
                        MatFormField,
                        MatIcon,
                        MatInput
                    ], template: "<mat-dialog-content>\r\n    <form>\r\n        <mat-form-field appearance=\"outline\">\r\n            <textarea matInput [(ngModel)]=\"data\" name=\"data\"></textarea>\r\n        </mat-form-field>\r\n    </form>\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions>\r\n    <button mat-raised-button color=\"warn\" mat-dialog-close=\"__DO!!NOT!!UPDATE__\">\r\n        <mat-icon>cancel</mat-icon>\r\n        <span>Cancel</span>\r\n    </button>\r\n\r\n    <button mat-raised-button color=\"primary\" [mat-dialog-close]=\"data\">\r\n        <mat-icon>done</mat-icon>\r\n        <span>Accept</span>\r\n    </button>\r\n</mat-dialog-actions>", styles: ["mat-dialog-content{height:95%;max-height:initial!important}form{width:100%}mat-form-field{width:100%}textarea{height:70vh}\n"] }]
        }] });

class EditorComponent {
    constructor() {
        this.#data = inject(MAT_DIALOG_DATA, { optional: true });
        this.#dialogRef = inject((MatDialogRef), { optional: true });
        this.#dialog = inject(MatDialog);
        this.editor = viewChild(QuillEditorComponent);
        this.onChange = (_) => { }; // Invoked when the model has been changed
        this.onTouched = () => { }; // Invoked when the model has been touched
        //#endregion
        this.config = model(DefaultConfig);
        this.placeholder = model();
        //#region These can be passed in as @Input(), or use values from config
        this.format = model();
        this.height = model();
        this.width = model();
        this.fullscreenHeight = model();
        this.fullscreenWidth = model();
        this.fullscreenMode = model();
        this.enableTooltips = model();
        this.fullscreen = model();
        this.readonly = model();
        this.applyReadonlyStyle = model();
        this.showToolbar = model();
        this.showBorder = model();
        //#region Optional Quill modules
        this.imageResizeModule = model();
        this.imageDropModule = model();
        this.syntaxModule = model();
        //#endregion
        //#endregion
        this.fullscreenChanged = output();
        //#region Passthrough events
        this.onBlur = output();
        this.onContentChanged = output();
        this.onEditorChanged = output();
        this.onEditorCreated = output();
        this.onFocus = output();
        this.onSelectionChanged = output();
    }
    get showBlockStyle() { return (this.config()?.buttons?.blockquote || this.config()?.buttons?.codeblock) ?? false; }
    ;
    get showFontStyle() { return (this.config()?.buttons?.bold || this.config()?.buttons?.italic || this.config()?.buttons?.strike || this.config()?.buttons?.underline) ?? false; }
    ;
    get showQuickHeadingStyle() { return (this.config()?.buttons?.h1 || this.config()?.buttons?.h2) ?? false; }
    ;
    get showIndentStyle() { return (this.config()?.buttons?.decreaseIndent || this.config()?.buttons?.increaseIndent) ?? false; }
    ;
    get showListStyle() { return (this.config()?.buttons?.bulleted || this.config()?.buttons?.ordered) ?? false; }
    ;
    get showMedia() { return (this.config()?.buttons?.link || this.config()?.buttons?.image || this.config()?.buttons?.video) ?? false; }
    ;
    get showScriptStyle() { return (this.config()?.buttons?.subScript || this.config()?.buttons?.superScript) ?? false; }
    ;
    #data;
    #dialogRef;
    #dialog;
    //#endregion
    ngOnInit() {
        this.initialize();
        /*if (!this.users) {
          this.activeDirectoryService.getUsers().subscribe(users =>
            this.users = users
          );
        }*/
    }
    initialize() {
        this.config.set({
            ...DefaultConfig,
            ...this.config(),
            ...this.#data?.config,
            buttons: this.config()?.buttons ?? DefaultButtons,
            icons: {
                ...DefaultIcons,
                ...this.config()?.icons
            },
            tooltips: {
                ...DefaultTooltips,
                ...this.config()?.tooltips
            }
        });
        this.value = this.value ?? this.#data?.value;
        // Moved to client responsibility
        /*if (this.imageDropModule) {
          Quill.register('modules/imageDrop', ImageDrop);
        }*/
        this.placeholder.set(this.placeholder() ?? this.#data?.placeholder);
        this.imageDropModule.set(this.imageDropModule() ?? this.#data?.imageDropModule ?? this.config().imageDropModule);
        this.imageResizeModule.set(this.imageResizeModule() ?? this.#data?.imageResizeModule ?? this.config().imageResizeModule);
        this.syntaxModule.set(this.syntaxModule() ?? this.#data?.syntaxModule ?? this.config().syntaxModule);
        this.format.set(this.format() ?? this.#data?.format ?? this.config().format);
        this.height.set(this.height() ?? this.#data?.height ?? this.config().height);
        this.width.set(this.width() ?? this.#data?.width ?? this.config().width);
        this.fullscreenHeight.set(this.fullscreenHeight() ?? this.#data?.maxHeight ?? this.config().fullscreenHeight);
        this.fullscreenWidth.set(this.fullscreenWidth() ?? this.#data?.maxWidth ?? this.config().fullscreenWidth);
        this.fullscreenMode.set(this.fullscreenMode() ?? this.#data?.fullscreenMode ?? this.config().fullscreenMode);
        this.enableTooltips.set(this.enableTooltips() !== undefined ?
            this.enableTooltips() :
            this.#data?.enableTooltips ?? this.config().enableTooltips);
        this.fullscreen.set(this.fullscreen() !== undefined ?
            this.fullscreen() :
            this.#data?.fullscreen ?? this.config().fullscreen);
        this.readonly.set(this.readonly() !== undefined ?
            this.readonly() :
            this.#data?.readonly ?? this.config().readonly);
        this.applyReadonlyStyle.set(this.applyReadonlyStyle() !== undefined ?
            this.applyReadonlyStyle() :
            this.#data?.applyReadonlyStyle ?? this.config().applyReadonlyStyle);
        this.showToolbar.set(this.showToolbar() !== undefined ?
            this.showToolbar() :
            this.#data?.showToolbar ?? this.config().showToolbar);
        this.showBorder.set(this.showBorder() !== undefined ?
            this.showBorder() :
            this.#data?.showBorder ?? this.config().showBorder);
    }
    toggleFullscreen() {
        if (this.fullscreenMode() === 'expand') {
            this.fullscreen.set(!this.fullscreen());
            this.fullscreenChanged.emit(this.fullscreen());
        }
        else {
            if (this.fullscreen()) {
                this.#dialogRef?.close(this.value);
                this.fullscreenChanged.emit(false);
            }
            else {
                const data = {
                    value: this.value,
                    config: this.config(),
                    placeholder: this.placeholder(),
                    format: this.format(),
                    height: this.fullscreenHeight(),
                    width: '100%',
                    maxHeight: this.fullscreenHeight(),
                    maxWidth: '100%',
                    enableTooltips: this.enableTooltips(),
                    fullscreen: true,
                    fullscreenMode: this.fullscreenMode(),
                    readonly: this.readonly(),
                    applyReadonlyStyle: this.applyReadonlyStyle(),
                    showToolbar: this.showToolbar(),
                    showBorder: this.showBorder(),
                    imageResizeModule: this.imageResizeModule(),
                    imageDropModule: this.imageDropModule(),
                    syntaxModule: this.syntaxModule()
                    //users: this.users
                };
                this.#dialog.open(EditorComponent, {
                    disableClose: true,
                    width: this.fullscreenWidth(),
                    height: this.fullscreenHeight(),
                    data
                })
                    .afterClosed()
                    .subscribe(value => {
                    this.value = value;
                    this.updateChanges();
                });
                this.fullscreenChanged.emit(true);
            }
        }
    }
    rawEdit() {
        this.#dialog.open(RawComponent, {
            data: this.value,
            disableClose: true,
            height: '90%',
            width: '100%'
        })
            .afterClosed()
            .subscribe(value => {
            if (value === '__DO!!NOT!!UPDATE__') {
                return;
            }
            this.value = value;
        });
    }
    tooltip(val) {
        return this.enableTooltips() ? val : '';
    }
    get modules() {
        //if (!this.users) { return undefined; }
        const modules = {};
        if (!this.showToolbar()) {
            modules['toolbar'] = [];
        }
        if (this.imageResizeModule()) {
            modules['imageResize'] = {};
        }
        if (this.imageDropModule()) {
            modules['imageDrop'] = true;
        }
        if (this.syntaxModule()) {
            modules['syntax'] = true;
        }
        /*if (this.mentionModule) {
          modules['mention'] = {
            allowedChars: /^[A-Za-z\sÅÄÖåäö]*$/,
    
            onSelect: (item: DOMStringMap, insertItem: any) => {
              const editor = this.editor!.quillEditor
              insertItem(item)
              // necessary because quill-mention triggers changes as 'api' instead of 'user'
              editor.insertText(editor.getLength() - 1, '', 'user')
            },
    
            source: (searchTerm: string, renderList: any) => {
              if (searchTerm.length === 0) {
                renderList(this.users?.map(u => ({ value: `${u.displayName} (${u.sAMAccountName.toLowerCase()})` })), searchTerm)
              } else {
                const matches: any[] = []
    
                this.users!.forEach((entry) => {
                  if (
                    entry.displayName.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1 ||
                    entry.sAMAccountName.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1
                    ) {
                    matches.push({ value: `${entry.displayName} (${entry.sAMAccountName.toLowerCase()})` })
                  }
                })
    
                renderList(matches, searchTerm)
              }
            }
          };
        }*/
        return modules;
    }
    //#region ControlValueAccessor methods
    // Method that is invoked on an update of a model.
    updateChanges() {
        this.onChange(this.value);
    }
    //#region ControlValueAccessor Overrides
    // Writes a new item to the element.
    writeValue(value) {
        this.value = value;
        this.updateChanges();
    }
    // Registers a callback function that should be called when the control's value changes in the UI.
    registerOnChange(fn) {
        this.onChange = fn;
    }
    // Registers a callback function that should be called when the control receives a blur event.
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: EditorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.0", type: EditorComponent, isStandalone: true, selector: "cpquill-editor", inputs: { config: { classPropertyName: "config", publicName: "config", isSignal: true, isRequired: false, transformFunction: null }, placeholder: { classPropertyName: "placeholder", publicName: "placeholder", isSignal: true, isRequired: false, transformFunction: null }, format: { classPropertyName: "format", publicName: "format", isSignal: true, isRequired: false, transformFunction: null }, height: { classPropertyName: "height", publicName: "height", isSignal: true, isRequired: false, transformFunction: null }, width: { classPropertyName: "width", publicName: "width", isSignal: true, isRequired: false, transformFunction: null }, fullscreenHeight: { classPropertyName: "fullscreenHeight", publicName: "fullscreenHeight", isSignal: true, isRequired: false, transformFunction: null }, fullscreenWidth: { classPropertyName: "fullscreenWidth", publicName: "fullscreenWidth", isSignal: true, isRequired: false, transformFunction: null }, fullscreenMode: { classPropertyName: "fullscreenMode", publicName: "fullscreenMode", isSignal: true, isRequired: false, transformFunction: null }, enableTooltips: { classPropertyName: "enableTooltips", publicName: "enableTooltips", isSignal: true, isRequired: false, transformFunction: null }, fullscreen: { classPropertyName: "fullscreen", publicName: "fullscreen", isSignal: true, isRequired: false, transformFunction: null }, readonly: { classPropertyName: "readonly", publicName: "readonly", isSignal: true, isRequired: false, transformFunction: null }, applyReadonlyStyle: { classPropertyName: "applyReadonlyStyle", publicName: "applyReadonlyStyle", isSignal: true, isRequired: false, transformFunction: null }, showToolbar: { classPropertyName: "showToolbar", publicName: "showToolbar", isSignal: true, isRequired: false, transformFunction: null }, showBorder: { classPropertyName: "showBorder", publicName: "showBorder", isSignal: true, isRequired: false, transformFunction: null }, imageResizeModule: { classPropertyName: "imageResizeModule", publicName: "imageResizeModule", isSignal: true, isRequired: false, transformFunction: null }, imageDropModule: { classPropertyName: "imageDropModule", publicName: "imageDropModule", isSignal: true, isRequired: false, transformFunction: null }, syntaxModule: { classPropertyName: "syntaxModule", publicName: "syntaxModule", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { config: "configChange", placeholder: "placeholderChange", format: "formatChange", height: "heightChange", width: "widthChange", fullscreenHeight: "fullscreenHeightChange", fullscreenWidth: "fullscreenWidthChange", fullscreenMode: "fullscreenModeChange", enableTooltips: "enableTooltipsChange", fullscreen: "fullscreenChange", readonly: "readonlyChange", applyReadonlyStyle: "applyReadonlyStyleChange", showToolbar: "showToolbarChange", showBorder: "showBorderChange", imageResizeModule: "imageResizeModuleChange", imageDropModule: "imageDropModuleChange", syntaxModule: "syntaxModuleChange", fullscreenChanged: "fullscreenChanged", onBlur: "onBlur", onContentChanged: "onContentChanged", onEditorChanged: "onEditorChanged", onEditorCreated: "onEditorCreated", onFocus: "onFocus", onSelectionChanged: "onSelectionChanged" }, providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => EditorComponent),
                multi: true
            }], viewQueries: [{ propertyName: "editor", first: true, predicate: QuillEditorComponent, descendants: true, isSignal: true }], ngImport: i0, template: "<ng-container>\r\n  <form>\r\n    <quill-editor name=\"editor\"\r\n      [(ngModel)]=\"value\"\r\n      (ngModelChange)=\"updateChanges()\"\r\n      [placeholder]=\"placeholder() ?? ''\"\r\n      [format]=\"format()\"\r\n      [style.height]=\"fullscreen() ? fullscreenHeight() : height()\"\r\n      [style.width]=\"fullscreen() ? fullscreenWidth() : width()\"\r\n      [readOnly]=\"readonly() ?? false\"\r\n      [class.readonly]=\"readonly() && applyReadonlyStyle()\"\r\n      [class.no-toolbar]=\"!showToolbar()\"\r\n      [class.no-border]=\"!showBorder()\"\r\n      [modules]=\"modules\"\r\n\r\n      (onBlur)=\"onBlur.emit($event)\"\r\n      (onContentChanged)=\"onContentChanged.emit($event)\"\r\n      (onEditorChanged)=\"onEditorChanged.emit($event)\"\r\n      (onEditorCreated)=\"onEditorCreated.emit()\"\r\n      (onFocus)=\"onFocus.emit($event)\"\r\n      (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\r\n\r\n      @if (showToolbar()) {\r\n        <div quill-editor-toolbar>\r\n          <ng-container [ngTemplateOutlet]=\"toolbar\"/>\r\n          <ng-container [ngTemplateOutlet]=\"editorSize\"/>\r\n        </div>\r\n      }\r\n    </quill-editor>\r\n  </form>\r\n</ng-container>\r\n\r\n<ng-template #toolbar>\r\n  <div>\r\n    <ng-container [ngTemplateOutlet]=\"fontStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"blockStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"headingStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"listStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"scriptStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"indentStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"rtl\"/>\r\n    <ng-container [ngTemplateOutlet]=\"fontSize\"/>\r\n    <ng-container [ngTemplateOutlet]=\"heading\"/>\r\n    <ng-container [ngTemplateOutlet]=\"color\"/>\r\n    <ng-container [ngTemplateOutlet]=\"font\"/>\r\n    <ng-container [ngTemplateOutlet]=\"align\"/>\r\n    <ng-container [ngTemplateOutlet]=\"clean\"/>\r\n    <ng-container [ngTemplateOutlet]=\"formula\"/>\r\n    <ng-container [ngTemplateOutlet]=\"media\"/>\r\n  </div>\r\n</ng-template>\r\n\r\n<ng-template #fontStyle>\r\n  @if (showFontStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.bold) {\r\n        <button class=\"ql-bold\"           [matTooltip]=\"tooltip(config()!.tooltips!.bold!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.italic) {\r\n        <button class=\"ql-italic\"       [matTooltip]=\"tooltip(config()!.tooltips!.italic!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.underline) {\r\n        <button class=\"ql-underline\" [matTooltip]=\"tooltip(config()!.tooltips!.underline!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.strike) {\r\n        <button class=\"ql-strike\"       [matTooltip]=\"tooltip(config()!.tooltips!.strike!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #blockStyle>\r\n  @if (showBlockStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.blockquote) {\r\n        <button class=\"ql-blockquote\" [matTooltip]=\"tooltip(config()!.tooltips!.blockquote!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.codeblock) {\r\n        <button class=\"ql-code-block\"  [matTooltip]=\"tooltip(config()!.tooltips!.codeblock!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #headingStyle>\r\n  @if (showQuickHeadingStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.h1) {\r\n        <button class=\"ql-header\" value=\"1\" [matTooltip]=\"tooltip(config()!.tooltips!.h1!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.h2) {\r\n        <button class=\"ql-header\" value=\"2\" [matTooltip]=\"tooltip(config()!.tooltips!.h2!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #listStyle>\r\n  @if (showListStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.ordered) {\r\n        <button class=\"ql-list\" value=\"ordered\"  [matTooltip]=\"tooltip(config()!.tooltips!.ordered!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.bulleted) {\r\n        <button class=\"ql-list\" value=\"bullet\"  [matTooltip]=\"tooltip(config()!.tooltips!.bulleted!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #scriptStyle>\r\n  @if (showScriptStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.subScript) {\r\n        <button class=\"ql-script\" value=\"sub\"   [matTooltip]=\"tooltip(config()!.tooltips!.subScript!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.superScript) {\r\n        <button class=\"ql-script\" value=\"super\" [matTooltip]=\"tooltip(config()!.tooltips!.superScript!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #indentStyle>\r\n  @if (showIndentStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.decreaseIndent) {\r\n        <button class=\"ql-indent\" value=\"-1\" [matTooltip]=\"tooltip(config()!.tooltips!.decreaseIndent!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.increaseIndent) {\r\n        <button class=\"ql-indent\" value=\"+1\" [matTooltip]=\"tooltip(config()!.tooltips!.increaseIndent!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #rtl>\r\n  @if (config()!.buttons!.rtl) {\r\n    <span class=\"ql-formats\">\r\n      <button class=\"ql-direction\" value=\"rtl\" [matTooltip]=\"tooltip(config()!.tooltips!.rtl!)\"></button>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #fontSize>\r\n  @if (config()!.buttons!.fontSize) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.fontSize!)\">\r\n      <select class=\"ql-size\">\r\n        <option value=\"small\"></option>\r\n        <option selected></option>\r\n        <option value=\"large\"></option>\r\n        <option value=\"huge\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #heading>\r\n  @if (config()!.buttons!.headingStyle) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.headingStyle!)\">\r\n      <select class=\"ql-header\">\r\n        <option value=\"1\"></option>\r\n        <option value=\"2\"></option>\r\n        <option value=\"3\"></option>\r\n        <option value=\"4\"></option>\r\n        <option value=\"5\"></option>\r\n        <option value=\"6\"></option>\r\n        <option selected=\"selected\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #color>\r\n  @if (config()!.buttons!.color) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.color!)\">\r\n      <select class=\"ql-color\"></select>\r\n      <select class=\"ql-background\"></select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #font>\r\n  @if (config()!.buttons!.font) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.font!)\">\r\n      <select class=\"ql-font\">\r\n        <option selected></option>\r\n        <option value=\"serif\"></option>\r\n        <option value=\"monospace\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #align>\r\n  @if (config()!.buttons!.align) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.align!)\">\r\n      <select class=\"ql-align\">\r\n        <option selected></option>\r\n        <option value=\"center\"></option>\r\n        <option value=\"right\"></option>\r\n        <option value=\"justify\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #clean>\r\n  @if (config()!.buttons!.clean) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.clean!)\">\r\n      <button class=\"ql-clean\"></button>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #media>\r\n  @if (showMedia) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.link) {\r\n        <button class=\"ql-link\"  [matTooltip]=\"tooltip(config()!.tooltips!.link!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.image) {\r\n        <button class=\"ql-image\" [matTooltip]=\"tooltip(config()!.tooltips!.image!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.video) {\r\n        <button class=\"ql-video\" [matTooltip]=\"tooltip(config()!.tooltips!.video!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #editorSize>\r\n  <div>\r\n    @if (config()!.buttons!.rawEditor) {\r\n      <span class=\"ql-formats\">\r\n        <button id=\"rawdog\"\r\n          [matTooltip]=\"tooltip(config()!.tooltips!.rawEditor!)\">\r\n          <mat-icon (click)=\"rawEdit()\">\r\n            code\r\n          </mat-icon>\r\n        </button>\r\n      </span>\r\n    }\r\n\r\n    @if (config()!.buttons!.editorSize) {\r\n      <span class=\"ql-formats\">\r\n        <button id=\"fullscreen\"\r\n                [matTooltip]=\"tooltip(fullscreen() ?\r\n                    (fullscreenMode() === 'expand' ? config()!.tooltips!.minimize! : config()!.tooltips!.popin!) :\r\n                    (fullscreenMode() === 'expand' ? config()!.tooltips!.maximize! : config()!.tooltips!.popout!))\">\r\n          <mat-icon (click)=\"toggleFullscreen()\">\r\n            {{ fullscreen() ?\r\n            (fullscreenMode() === 'expand' ? config()!.icons!.minimize : config()!.icons!.popin) :\r\n            (fullscreenMode() === 'expand' ? config()!.icons!.maximize : config()!.icons!.popout)\r\n            }}\r\n          </mat-icon>\r\n        </button>\r\n      </span>\r\n    }\r\n  </div>\r\n</ng-template>\r\n\r\n<ng-template #formula>\r\n  @if (config()!.buttons!.formula) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.formula!)\">\r\n      <button class=\"ql-formula\"></button>\r\n    </span>\r\n  }\r\n</ng-template>", styles: [".ql-toolbar{display:grid;grid-template-columns:1fr auto}mat-icon{color:#ff4500}quill-editor.readonly .ql-toolbar{opacity:.5}::ng-deep quill-editor.no-toolbar .ql-toolbar{height:0;padding:0;visibility:hidden}::ng-deep quill-editor.no-border .ql-container{border:none}::ng-deep quill-editor.readonly .ql-container{background-color:#f5f5f5!important}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: MatTooltip, selector: "[matTooltip]", inputs: ["matTooltipPosition", "matTooltipPositionAtOrigin", "matTooltipDisabled", "matTooltipShowDelay", "matTooltipHideDelay", "matTooltipTouchGestures", "matTooltip", "matTooltipClass"], exportAs: ["matTooltip"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: QuillEditorComponent, selector: "quill-editor" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: EditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cpquill-editor', standalone: true, imports: [
                        FormsModule,
                        MatIcon,
                        MatTooltip,
                        NgTemplateOutlet,
                        QuillEditorComponent,
                    ], providers: [{
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => EditorComponent),
                            multi: true
                        }], template: "<ng-container>\r\n  <form>\r\n    <quill-editor name=\"editor\"\r\n      [(ngModel)]=\"value\"\r\n      (ngModelChange)=\"updateChanges()\"\r\n      [placeholder]=\"placeholder() ?? ''\"\r\n      [format]=\"format()\"\r\n      [style.height]=\"fullscreen() ? fullscreenHeight() : height()\"\r\n      [style.width]=\"fullscreen() ? fullscreenWidth() : width()\"\r\n      [readOnly]=\"readonly() ?? false\"\r\n      [class.readonly]=\"readonly() && applyReadonlyStyle()\"\r\n      [class.no-toolbar]=\"!showToolbar()\"\r\n      [class.no-border]=\"!showBorder()\"\r\n      [modules]=\"modules\"\r\n\r\n      (onBlur)=\"onBlur.emit($event)\"\r\n      (onContentChanged)=\"onContentChanged.emit($event)\"\r\n      (onEditorChanged)=\"onEditorChanged.emit($event)\"\r\n      (onEditorCreated)=\"onEditorCreated.emit()\"\r\n      (onFocus)=\"onFocus.emit($event)\"\r\n      (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\r\n\r\n      @if (showToolbar()) {\r\n        <div quill-editor-toolbar>\r\n          <ng-container [ngTemplateOutlet]=\"toolbar\"/>\r\n          <ng-container [ngTemplateOutlet]=\"editorSize\"/>\r\n        </div>\r\n      }\r\n    </quill-editor>\r\n  </form>\r\n</ng-container>\r\n\r\n<ng-template #toolbar>\r\n  <div>\r\n    <ng-container [ngTemplateOutlet]=\"fontStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"blockStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"headingStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"listStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"scriptStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"indentStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"rtl\"/>\r\n    <ng-container [ngTemplateOutlet]=\"fontSize\"/>\r\n    <ng-container [ngTemplateOutlet]=\"heading\"/>\r\n    <ng-container [ngTemplateOutlet]=\"color\"/>\r\n    <ng-container [ngTemplateOutlet]=\"font\"/>\r\n    <ng-container [ngTemplateOutlet]=\"align\"/>\r\n    <ng-container [ngTemplateOutlet]=\"clean\"/>\r\n    <ng-container [ngTemplateOutlet]=\"formula\"/>\r\n    <ng-container [ngTemplateOutlet]=\"media\"/>\r\n  </div>\r\n</ng-template>\r\n\r\n<ng-template #fontStyle>\r\n  @if (showFontStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.bold) {\r\n        <button class=\"ql-bold\"           [matTooltip]=\"tooltip(config()!.tooltips!.bold!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.italic) {\r\n        <button class=\"ql-italic\"       [matTooltip]=\"tooltip(config()!.tooltips!.italic!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.underline) {\r\n        <button class=\"ql-underline\" [matTooltip]=\"tooltip(config()!.tooltips!.underline!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.strike) {\r\n        <button class=\"ql-strike\"       [matTooltip]=\"tooltip(config()!.tooltips!.strike!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #blockStyle>\r\n  @if (showBlockStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.blockquote) {\r\n        <button class=\"ql-blockquote\" [matTooltip]=\"tooltip(config()!.tooltips!.blockquote!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.codeblock) {\r\n        <button class=\"ql-code-block\"  [matTooltip]=\"tooltip(config()!.tooltips!.codeblock!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #headingStyle>\r\n  @if (showQuickHeadingStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.h1) {\r\n        <button class=\"ql-header\" value=\"1\" [matTooltip]=\"tooltip(config()!.tooltips!.h1!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.h2) {\r\n        <button class=\"ql-header\" value=\"2\" [matTooltip]=\"tooltip(config()!.tooltips!.h2!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #listStyle>\r\n  @if (showListStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.ordered) {\r\n        <button class=\"ql-list\" value=\"ordered\"  [matTooltip]=\"tooltip(config()!.tooltips!.ordered!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.bulleted) {\r\n        <button class=\"ql-list\" value=\"bullet\"  [matTooltip]=\"tooltip(config()!.tooltips!.bulleted!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #scriptStyle>\r\n  @if (showScriptStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.subScript) {\r\n        <button class=\"ql-script\" value=\"sub\"   [matTooltip]=\"tooltip(config()!.tooltips!.subScript!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.superScript) {\r\n        <button class=\"ql-script\" value=\"super\" [matTooltip]=\"tooltip(config()!.tooltips!.superScript!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #indentStyle>\r\n  @if (showIndentStyle) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.decreaseIndent) {\r\n        <button class=\"ql-indent\" value=\"-1\" [matTooltip]=\"tooltip(config()!.tooltips!.decreaseIndent!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.increaseIndent) {\r\n        <button class=\"ql-indent\" value=\"+1\" [matTooltip]=\"tooltip(config()!.tooltips!.increaseIndent!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #rtl>\r\n  @if (config()!.buttons!.rtl) {\r\n    <span class=\"ql-formats\">\r\n      <button class=\"ql-direction\" value=\"rtl\" [matTooltip]=\"tooltip(config()!.tooltips!.rtl!)\"></button>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #fontSize>\r\n  @if (config()!.buttons!.fontSize) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.fontSize!)\">\r\n      <select class=\"ql-size\">\r\n        <option value=\"small\"></option>\r\n        <option selected></option>\r\n        <option value=\"large\"></option>\r\n        <option value=\"huge\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #heading>\r\n  @if (config()!.buttons!.headingStyle) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.headingStyle!)\">\r\n      <select class=\"ql-header\">\r\n        <option value=\"1\"></option>\r\n        <option value=\"2\"></option>\r\n        <option value=\"3\"></option>\r\n        <option value=\"4\"></option>\r\n        <option value=\"5\"></option>\r\n        <option value=\"6\"></option>\r\n        <option selected=\"selected\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #color>\r\n  @if (config()!.buttons!.color) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.color!)\">\r\n      <select class=\"ql-color\"></select>\r\n      <select class=\"ql-background\"></select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #font>\r\n  @if (config()!.buttons!.font) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.font!)\">\r\n      <select class=\"ql-font\">\r\n        <option selected></option>\r\n        <option value=\"serif\"></option>\r\n        <option value=\"monospace\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #align>\r\n  @if (config()!.buttons!.align) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.align!)\">\r\n      <select class=\"ql-align\">\r\n        <option selected></option>\r\n        <option value=\"center\"></option>\r\n        <option value=\"right\"></option>\r\n        <option value=\"justify\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #clean>\r\n  @if (config()!.buttons!.clean) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.clean!)\">\r\n      <button class=\"ql-clean\"></button>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #media>\r\n  @if (showMedia) {\r\n    <span class=\"ql-formats\">\r\n      @if (config()!.buttons!.link) {\r\n        <button class=\"ql-link\"  [matTooltip]=\"tooltip(config()!.tooltips!.link!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.image) {\r\n        <button class=\"ql-image\" [matTooltip]=\"tooltip(config()!.tooltips!.image!)\"></button>\r\n      }\r\n      @if (config()!.buttons!.video) {\r\n        <button class=\"ql-video\" [matTooltip]=\"tooltip(config()!.tooltips!.video!)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #editorSize>\r\n  <div>\r\n    @if (config()!.buttons!.rawEditor) {\r\n      <span class=\"ql-formats\">\r\n        <button id=\"rawdog\"\r\n          [matTooltip]=\"tooltip(config()!.tooltips!.rawEditor!)\">\r\n          <mat-icon (click)=\"rawEdit()\">\r\n            code\r\n          </mat-icon>\r\n        </button>\r\n      </span>\r\n    }\r\n\r\n    @if (config()!.buttons!.editorSize) {\r\n      <span class=\"ql-formats\">\r\n        <button id=\"fullscreen\"\r\n                [matTooltip]=\"tooltip(fullscreen() ?\r\n                    (fullscreenMode() === 'expand' ? config()!.tooltips!.minimize! : config()!.tooltips!.popin!) :\r\n                    (fullscreenMode() === 'expand' ? config()!.tooltips!.maximize! : config()!.tooltips!.popout!))\">\r\n          <mat-icon (click)=\"toggleFullscreen()\">\r\n            {{ fullscreen() ?\r\n            (fullscreenMode() === 'expand' ? config()!.icons!.minimize : config()!.icons!.popin) :\r\n            (fullscreenMode() === 'expand' ? config()!.icons!.maximize : config()!.icons!.popout)\r\n            }}\r\n          </mat-icon>\r\n        </button>\r\n      </span>\r\n    }\r\n  </div>\r\n</ng-template>\r\n\r\n<ng-template #formula>\r\n  @if (config()!.buttons!.formula) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config()!.tooltips!.formula!)\">\r\n      <button class=\"ql-formula\"></button>\r\n    </span>\r\n  }\r\n</ng-template>", styles: [".ql-toolbar{display:grid;grid-template-columns:1fr auto}mat-icon{color:#ff4500}quill-editor.readonly .ql-toolbar{opacity:.5}::ng-deep quill-editor.no-toolbar .ql-toolbar{height:0;padding:0;visibility:hidden}::ng-deep quill-editor.no-border .ql-container{border:none}::ng-deep quill-editor.readonly .ql-container{background-color:#f5f5f5!important}\n"] }]
        }] });

class QuillModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('QuillModule is already loaded. Import it in the AppModule only');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: QuillModule, deps: [{ token: QuillModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: QuillModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatFormFieldModule,
            MatIconModule,
            MatInputModule,
            MatTooltipModule,
            QuillModule$1,
            EditorComponent,
            RawComponent], exports: [EditorComponent,
            RawComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: QuillModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatFormFieldModule,
            MatIconModule,
            MatInputModule,
            MatTooltipModule,
            QuillModule$1,
            EditorComponent,
            RawComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: QuillModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatIconModule,
                        MatInputModule,
                        MatTooltipModule,
                        QuillModule$1,
                        EditorComponent,
                        RawComponent
                    ],
                    exports: [
                        EditorComponent,
                        RawComponent
                    ]
                }]
        }], ctorParameters: () => [{ type: QuillModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DefaultButtons, DefaultConfig, DefaultIcons, DefaultTooltips, EditorComponent, QuillModule, RawComponent };
//# sourceMappingURL=cleavelandprice-ngx-lib-quill.mjs.map
